@@ -4,14 +4,19 @@ from __future__ import (absolute_import, division, print_function,
 from .geom_abline import geom_abline
 from .geom_area import geom_area
 from .geom_bar import geom_bar
+from .geom_blank import geom_blank
+from .geom_boxplot import geom_boxplot
 from .geom_density import geom_density
+from .geom_dotplot import geom_dotplot
 from .geom_histogram import geom_histogram
 from .geom_hline import geom_hline
 from .geom_jitter import geom_jitter
 from .geom_line import geom_line
+from .geom_linerange import geom_linerange
 from .geom_now_its_art import geom_now_its_art
 from .geom_path import geom_path
 from .geom_point import geom_point
+from .geom_pointrange import geom_pointrange
 from .geom_rect import geom_rect
 from .geom_smooth import geom_smooth
 from .geom_step import geom_step
@@ -25,9 +30,10 @@ from .facet_wrap import facet_wrap
 from .chart_components import *
 
 __facet__ = ['facet_grid', 'facet_wrap']
-__geoms__ = ['geom_abline', 'geom_area', 'geom_bar', 'geom_density',
-             'geom_histogram', 'geom_hline', 'geom_jitter', 'geom_line',
-             'geom_now_its_art', 'geom_path', 'geom_point', 'geom_rect',
+__geoms__ = ['geom_abline', 'geom_area', 'geom_bar', 'geom_boxplot', 'geom_density',
+            'geom_dotplot', 'geom_blank', 'geom_linerange', 'geom_pointrange',
+             'geom_histogram', 'geom_hline', 'geom_jitter', 'geom_line', 'geom_linerange',
+             'geom_now_its_art', 'geom_path', 'geom_point', 'geom_pointrange', 'geom_rect',
              'geom_step', 'geom_smooth', 'geom_text', 'geom_tile',
              'geom_vline']
 __components__ = ['ylab', 'xlab', 'ylim', 'xlim', 'labs', 'ggtitle']
