@@ -1,4 +1,3 @@
-import matplotlib as mpl
 from .theme_gray import theme_gray
 
 
@@ -6,6 +5,7 @@ class theme_bw(theme_gray):
     """
     White background w/ black gridlines
     """
+
     def __init__(self):
-        super(theme_gray, self).__init__()
-        mpl.rcParams['axes.facecolor'] = 'white'
+        super(theme_bw, self).__init__()
+        self._rcParams['axes.facecolor'] = 'white'
